@@ -337,7 +337,7 @@ def getWikiDataLIST(parseResultDICT, indexWithPOS=True):
 
 
 class LawsToolkit:
-    def __init__(self, articutResult):
+    def __init__(self, articutResult=None):
         self.articutResult = articutResult
         self.articlePat = re.compile("<KNOWLEDGE_lawTW>[^<]+?</KNOWLEDGE_lawTW>")
         self.crimePat = re.compile("(?<=[犯判決]</ACTION_verb>)[^犯罪]*?(>(?=<KNOWLEDGE_lawTW>第)|罪(?=<))")
@@ -370,6 +370,7 @@ class LawsToolkit:
     def getCriminalResponsibility(self, parseResultDICT={}):
         '''
         取得刑責
+        To be deprecated soon.
         '''
         if parseResultDICT:
             self.articutResult = parseResultDICT
@@ -380,6 +381,13 @@ class LawsToolkit:
         except KeyError:
             return []
 
+    def getPenalty(self, parseResultDICT={}):
+        '''
+        取得刑責。
+        Dummy Function of getCriminalResponsibility()
+        '''
+        return self.getCriminalResponsibility(parseResultDICT)
+
     def getEventRef(self, parseResultDICT={}):
         '''
         取得「所受(之)XX」的列表
